@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: unset.c,v 1.99.2.4 2008/03/12 03:09:17 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: unset.c,v 1.99.2.7 2008/12/15 03:44:22 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - unset.c */
@@ -1137,6 +1137,7 @@ unset_tics(AXIS_INDEX axis)
 	axis_array[i].ticdef.textcolor.lt = 0;
 	axis_array[i].ticdef.textcolor.value = 0;
 	axis_array[i].ticdef.offset = tics_nooffset;
+	axis_array[i].ticdef.rangelimited = FALSE;
 	axis_array[i].tic_rotate = 0;
 	axis_array[i].ticscale = 1.0;
 	axis_array[i].miniticscale = 0.5;
@@ -1502,6 +1503,7 @@ unset_view()
 {
     splot_map_deactivate();
     splot_map = FALSE;
+    aspect_ratio_3D = 0;
     surface_rot_z = 30.0;
     surface_rot_x = 60.0;
     surface_scale = 1.0;
